==> ducktools_pythonfinder-0.7.5.tar.gz: ducktools_pythonfinder-0.7.5/src/ducktools/pythonfinder/__init__.py <==
# ducktools-pythonfinder
# MIT License
#
# Copyright (c) 2023-2024 David C Ellis
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

# Find platform python versions

__all__ = [
    "__version__",
    "get_python_installs",
    "list_python_installs",
    "PythonInstall",
]

import sys
from ._version import __version__
from .shared import PythonInstall


if sys.platform == "win32":
    from .win32 import get_python_installs
elif sys.platform == "darwin":
    from .darwin import get_python_installs
else:
    from .linux import get_python_installs


def list_python_installs(*, query_executables=True):
    return sorted(
        get_python_installs(query_executables=query_executables),
        reverse=True,
        key=lambda x: (x.version[3], *x.version[:3], x.version[4])
    )

==> ducktools_pythonfinder-0.8.0.tar.gz: ducktools_pythonfinder-0.8.0/src/ducktools/pythonfinder/__init__.py <==
# ducktools-pythonfinder
# MIT License
#
# Copyright (c) 2023-2025 David C Ellis
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

# Find platform python versions

__all__ = [
    "__version__",
    "get_python_installs",
    "list_python_installs",
    "PythonInstall",
]

import sys
from ._version import __version__
from .shared import PythonInstall, DetailFinder


if sys.platform == "win32":
    from .win32 import get_python_installs
elif sys.platform == "darwin":
    from .darwin import get_python_installs
else:
    from .linux import get_python_installs


def list_python_installs(*, query_executables: bool = True, finder: "DetailFinder | None" = None):
    finder = DetailFinder() if finder is None else finder
    return sorted(
        get_python_installs(query_executables=query_executables, finder=finder),
        reverse=True,
        key=lambda x: (x.version[3], *x.version[:3], x.version[4])
    )
